@@ -497,11 +497,14 @@ OC.L10N.register(
     "Error" : "Error",
     "Active" : "Activa",
     "Expired" : "Caducó",
+    "Never" : "Enxamás",
     "Language" : "Llingua",
     "Country" : "País",
     "Status" : "Estáu",
     "Created at" : "Data de creación",
     "Limits" : "Llendes",
+    "Yes" : "Sí",
+    "No" : "Non",
     "_%n user_::_%n users_" : ["%n usuariu","%n usuarios"],
     "Installed version: {version}" : "Versión instalada: {version}",
     "Downloading …" : "Baxando…",
@@ -530,8 +533,8 @@ OC.L10N.register(
     "Confirm" : "Confirmar",
     "Reset" : "Reafitar",
     "Room {roomNumber}" : "Sala {roomNumber}",
-    "Back" : "Atrás",
     "Cancel" : "Encaboxar",
+    "Back" : "Atrás",
     "Now" : "Agora",
     "Loading …" : "Cargando…",
     "From" : "De",
@@ -592,15 +595,13 @@ OC.L10N.register(
     "Matterbridge" : "Matterbridge",
     "Bots" : "Robós",
     "Danger zone" : "Zona de peligru",
+    "Leave conversation" : "Colar de la conversación",
+    "Delete conversation" : "Desaniciar la conversación",
     "Error while deleting conversation" : "Hebo un error mentanto se desaniciaba la conversación",
+    "Delete all chat messages" : "Desaniciar los mensaxes de toles charres",
     "Error while clearing chat history" : "Hebo un error mentanto se borraba l'historial de la charra",
     "Be careful, these actions cannot be undone." : "Ten curiáu, estes aiciones nun se puen desfacer.",
-    "Leave conversation" : "Colar de la conversación",
-    "No" : "Non",
-    "Yes" : "Sí",
-    "Delete conversation" : "Desaniciar la conversación",
     "Delete chat messages" : "Desaniciar los mensaxes de la charra",
-    "Delete all chat messages" : "Desaniciar los mensaxes de toles charres",
     "_%n hour_::_%n hours_" : ["%n hora","%n hores"],
     "_%n day_::_%n days_" : ["%n día","%n díes"],
     "_%n week_::_%n weeks_" : ["%n selmana","%n selmanes"],
@@ -613,6 +614,7 @@ OC.L10N.register(
     "This conversation is limited to the current participants" : "Esta conversación ta llendada a los participantes actuales",
     "Error occurred when opening or limiting the conversation" : "Prodúxose un error al abrir o llendar la conversación",
     "Open conversation" : "Abrir la conversación",
+    "Invalid language" : "La llingua ye inválida",
     "Error occurred while updating start time" : "Prodúxose un error mentanto s'anovaba la hora de comienzu",
     "Error occurred when locking the conversation" : "Prodúxose un error mentanto se bloquiaba la conversación",
     "Error occurred when unlocking the conversation" : "Prodúxose un error mentanto se desbloquiaba la conversación",
@@ -646,6 +648,7 @@ OC.L10N.register(
     "Decline invitation" : "Refugar la invitación",
     "Accept invitation" : "Aceptar la invitación",
     "No pending invitations" : "Nun hai nenguna invitación pendiente",
+    "Home" : "Aniciu",
     "Unread" : "Ensin lleer",
     "No matches found" : "Nun s'atopó nenguna coincidencia",
     "No conversations found" : "Nun s'atopó nenguna conversación",
@@ -683,9 +686,8 @@ OC.L10N.register(
     "Blur" : "Emborrinar",
     "Upload" : "Xunir",
     "Files" : "Ficheros",
-    "Message sent" : "Unvióse'l mensaxe",
-    "Deleting message" : "Desaniciando'l mensaxe",
-    "An error occurred while deleting the message" : "Prodúxose un error mentanto se desaniciaba'l mensaxe",
+    "(edited)" : "(editóse)",
+    "The message has expired or has been deleted" : "El mensaxe caducó o desanicióse",
     "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
     "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
     "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
@@ -695,6 +697,7 @@ OC.L10N.register(
     "Error occurred when removing a reminder" : "Prodúxose un error al quitar un recordatoriu",
     "Error occurred when creating a reminder" : "Prodúxose un error al crear un recordatoriu",
     "Reply" : "Responder",
+    "More actions" : "Más aiciones",
     "Set reminder" : "Configurar un recordatoriu",
     "Reply privately" : "Responder per privao",
     "Edit message" : "Editar el mensaxe",
@@ -710,26 +713,22 @@ OC.L10N.register(
     "Translate message" : "Traducir el mensaxe",
     "Translating" : "Traduciendo",
     "Copy translated text" : "Copiar el testu traducíu",
+    "Message sent" : "Unvióse'l mensaxe",
+    "Deleting message" : "Desaniciando'l mensaxe",
+    "An error occurred while deleting the message" : "Prodúxose un error mentanto se desaniciaba'l mensaxe",
     "Contact" : "Contautu",
     "Sending message" : "Unviando'l mensaxe",
     "Not enough free space to upload file" : "Nun hai abondu espaciu llibre pa xubir el ficheru",
     "You are not allowed to share files" : "Nun tienes permisu pa compartir ficheros",
     "You cannot send messages to this conversation at the moment" : "Pel momentu, nun pues unviar mensaxes a esta conversación",
-    "Code block copied to clipboard" : "El bloque de códigu copióse nel cartafueyu",
-    "Code block could not be copied" : "Nun se pudo copiar el bloque de códigu",
-    "Copy code block" : "Copiar el bloque de códigu",
     "Open poll • You voted already" : "Encuesta abierta • Yá votesti",
     "Open poll • Click to vote" : "Encuesta abierta • Calca pa votar",
     "Poll • Ended" : "Encuesta • Finó",
     "Poll" : "Encuesta",
     "See results" : "Ver los resultaos",
+    "Reactions" : "Reaiciones",
     "Show all reactions" : "Amosar toles reaiciones",
     "Add more reactions" : "Amestar más reaiciones",
-    "Reactions" : "Reaiciones",
-    "Today" : "Güei",
-    "Yesterday" : "Ayeri",
-    "A week ago" : "Hai una selmana",
-    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n díes"],
     "No messages" : "Nun hai nengún mensaxe",
     "Add participants" : "Amestar participantes",
     "Conversation visibility" : "Visibilidá de la conversación",
@@ -770,7 +769,6 @@ OC.L10N.register(
     "Submit vote" : "Unviar el votu",
     "Change your vote" : "Cambiar el votu",
     "End poll" : "Finar la encuesta",
-    "The message has expired or has been deleted" : "El mensaxe caducó o desanicióse",
     "Send a message to \"{roomName}\"" : "¿Quies unviar un mensaxe a «{roomName}»?",
     "Show list of participants" : "Amosar la llista de participantes",
     "The message was sent to \"{roomName}\"" : "El mensaxe unvióse a «{roomName}»",
@@ -825,20 +823,13 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Nun se pue guardar la configuración de los soníos",
     "Sounds setting saved" : "Guardóse la configuración de los soníos",
     "Error while saving sounds setting" : "Hebo un error mentanto se guardaba la configuración de soníu",
-    "Browse …" : "Restolar…",
-    "Appearance" : "Aspeutu",
+    "Notification settings" : "Configuración de los avisos",
     "Privacy" : "Privacidá",
-    "Sounds" : "Soníos",
-    "Performance" : "Rindimientu",
-    "Keyboard shortcuts" : "Atayos del tecláu",
     "Search" : "Buscar",
-    "Space bar" : "Barra d'espaciu",
-    "More actions" : "Más aiciones",
     "Start call" : "Aniciar la llamada",
     "End call" : "Finar la llamada",
     "Stop recording" : "Parar la grabación",
     "Send a reaction" : "Unviar una reaición",
-    "Default" : "Por defeutu",
     "_%n participant in call_::_%n participants in call_" : ["%n participante na llamada","%n participantes na llamada"],
     "You are not allowed to enable screensharing" : "Nun tienes permisu p'activar la compartición de pantalla",
     "Screensharing options" : "Opciones de la compartición de pantalla",
@@ -906,11 +897,11 @@ OC.L10N.register(
     "Show all polls" : "Amosar toles encuestes",
     "Show all voice messages" : "Amosar tolos mensaxe de voz",
     "Show all locations" : "Amosar tolos llugares",
+    "Default" : "Por defeutu",
     "Group" : "Grupu",
     "Team" : "Equipu",
     "You and {user0} left the call" : "Tu y {user0} colestis de la canal",
     "You: {lastMessage}" : "Tu: {lastMessage}",
-    "(edited)" : "(editóse)",
     "Leave this page" : "Colar d'esta páxina",
     "In conversation" : "Na conversación",
     "Error while clearing conversation history" : "Hebo un error mentanto se borraba l'historial de la conversación",
@@ -953,13 +944,21 @@ OC.L10N.register(
     "Notes" : "Notes",
     "Reports" : "Informes",
     "Call summary" : "Resume de llamaes",
-    "You tried to call {user}" : "Tentesti de llamar a {user}",
     "You were invited to a conversation." : "Convidáronte a una conversación.",
-    "{user} invited you to a private conversation" : "{user} convidóte a una conversación privada",
-    "Copy conversation link" : "Copiar l'enllaz de la conversación",
     "Media settings" : "Configuración multimedia",
     "Normal call" : "Llamada normal",
-    "Close" : "Zarrar",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Anovóse Nextcloud Talk. Tienes de volver cargar la páxina enantes de poder aniciar o xunite a una llamada."
+    "Code block copied to clipboard" : "El bloque de códigu copióse nel cartafueyu",
+    "Code block could not be copied" : "Nun se pudo copiar el bloque de códigu",
+    "Copy code block" : "Copiar el bloque de códigu",
+    "Today" : "Güei",
+    "Yesterday" : "Ayeri",
+    "A week ago" : "Hai una selmana",
+    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n díes"],
+    "Browse …" : "Restolar…",
+    "Appearance" : "Aspeutu",
+    "Sounds" : "Soníos",
+    "Performance" : "Rindimientu",
+    "Keyboard shortcuts" : "Atayos del tecláu",
+    "Space bar" : "Barra d'espaciu"
 },
 "nplurals=2; plural=(n != 1);");
