@@ -557,6 +557,7 @@ OC.L10N.register(
     "Blocked" : "Estetty",
     "Active" : "Aktiivinen",
     "Expired" : "Vanhentunut",
+    "Never" : "Ei koskaan",
     "The account could not be deleted. Please try again later." : "Tätä tiliä ei voitu poistaa. Yritä myöhemmin uudelleen.",
     "URL of this Nextcloud instance" : "Tämän Nextcloud-instanssin URL-osoite",
     "Email of the user" : "Käyttäjän sähköpostiosoite",
@@ -565,6 +566,8 @@ OC.L10N.register(
     "Status" : "Tila",
     "Created at" : "Luotu",
     "Expires at" : "Vanhenee",
+    "Yes" : "Kyllä",
+    "No" : "Ei",
     "_%n user_::_%n users_" : ["%n käyttäjä","%n käyttäjää"],
     "Installed version: {version}" : "Asennettu versio: {version}",
     "Matterbridge binary was not found or couldn't be executed." : "Matterbridge-binääriä ei löytynyt tai sitä ei voitu suorittaa.",
@@ -610,11 +613,11 @@ OC.L10N.register(
     "Create breakout rooms" : "Luo pienryhmätilat",
     "Reset" : "Palauta",
     "Delete breakout rooms" : "Poista pienryhmätilat",
-    "Current breakout rooms and settings will be lost" : "Nykyisen pienryhmätilat ja asetukset katoavat",
     "Room {roomNumber}" : "Huone {roomNumber}",
+    "Current breakout rooms and settings will be lost" : "Nykyisen pienryhmätilat ja asetukset katoavat",
+    "Cancel" : "Peruuta",
     "Unassigned participants" : "Osallistujat joita ei ole määritetty",
     "Back" : "Takaisin",
-    "Cancel" : "Peruuta",
     "Add participant \"{user}\"" : "Lisää osallistuja \"{user}\"",
     "Now" : "Nyt",
     "Loading …" : "Ladataan…",
@@ -734,19 +737,17 @@ OC.L10N.register(
     "Matterbridge" : "Matterbridge",
     "Bots" : "Botit",
     "Danger zone" : "Vaaravyöhyke",
+    "Leave conversation" : "Poistu keskustelusta",
+    "Delete conversation" : "Poista keskustelu",
     "Do you really want to delete \"{displayName}\"?" : "Poistetaanko \"{displayName}\"?",
     "Error while deleting conversation" : "Virhe keskustelua poistaessa",
+    "Delete all chat messages" : "Poista kaikki keskustelun viestit",
     "Error while clearing chat history" : "Virhe keskusteluhistoriaa siivotessa",
     "Be careful, these actions cannot be undone." : "Ole varovainen, näitä toimintoja ei voi perua.",
-    "Leave conversation" : "Poistu keskustelusta",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Kun olet kerran poistunut suljetusta keskustelusta, tarvitset kutsun liittyäksesi uudelleen siihen. Avoimeen keskusteluun on mahdollista liittyä milloin hyvänsä.",
-    "No" : "Ei",
-    "Yes" : "Kyllä",
-    "Delete conversation" : "Poista keskustelu",
     "Permanently delete this conversation." : "Poista tämä keskustelu pysyvästi.",
     "Delete chat messages" : "Poista keskustelun viestit",
     "Permanently delete all the messages in this conversation." : "Poista pysyvästi kaikki tämän keskustelun viestit.",
-    "Delete all chat messages" : "Poista kaikki keskustelun viestit",
     "_%n hour_::_%n hours_" : ["%n tunti","%n tuntia"],
     "_%n day_::_%n days_" : ["%n päivä","%n päivää"],
     "_%n week_::_%n weeks_" : ["%n viikko","%n viikkoa"],
@@ -882,14 +883,9 @@ OC.L10N.register(
     "Blur" : "Sumennus",
     "Upload" : "Lähetä",
     "Files" : "Tiedostot",
-    "Message read by everyone who shares their reading status" : "Viesti luettu kaikkien niiden kanssa, jotka jakavat lukutilapäivityksensä",
-    "Message sent" : "Viesti lähetetty",
-    "Deleting message" : "Poistetaan viestiä",
-    "Message deleted successfully" : "Viesti poistettu onnistuneesti",
-    "Message could not be deleted because it is too old" : "Viestiä ei voitu poistaa, koska se on liian vanha",
-    "Only normal chat messages can be deleted" : "Vain normaaleja keskustelun viestejä on mahdollista poistaa",
-    "An error occurred while deleting the message" : "Virhe viestiä poistaessa",
-    "Show or collapse system messages" : "Näytä tai piilota järjestelmäviestit",
+    "(edited)" : "(muokattu)",
+    "The message has expired or has been deleted" : "Tämä viesti on vanhentunut tai se on poistettu",
+    "Cancel quote" : "Peruuta lainaus",
     "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
     "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
     "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
@@ -903,6 +899,7 @@ OC.L10N.register(
     "Message text could not be copied" : "Viestin tekstiä ei voitu kopioida",
     "Add a reaction to this message" : "Lisää reaktio tähän viestiin",
     "Reply" : "Vastaa",
+    "More actions" : "Lisää toimintoja",
     "Set reminder" : "Aseta muistutus",
     "Reply privately" : "Vastaa yksityisesti",
     "Edit message" : "Muokkaa viestiä",
@@ -929,6 +926,13 @@ OC.L10N.register(
     "Translate to" : "Kohdekieli",
     "Translating" : "Käännetään",
     "Copy translated text" : "Kopioi käännetty teksti",
+    "Message read by everyone who shares their reading status" : "Viesti luettu kaikkien niiden kanssa, jotka jakavat lukutilapäivityksensä",
+    "Message sent" : "Viesti lähetetty",
+    "Deleting message" : "Poistetaan viestiä",
+    "Message deleted successfully" : "Viesti poistettu onnistuneesti",
+    "Message could not be deleted because it is too old" : "Viestiä ei voitu poistaa, koska se on liian vanha",
+    "Only normal chat messages can be deleted" : "Vain normaaleja keskustelun viestejä on mahdollista poistaa",
+    "An error occurred while deleting the message" : "Virhe viestiä poistaessa",
     "Your browser does not support playing audio files" : "Selaimesi ei tue äänitiedostojen toistamista",
     "Contact" : "Yhteystieto",
     "Remove {fileName}" : "Poista {fileName}",
@@ -938,19 +942,13 @@ OC.L10N.register(
     "Not enough free space to upload file" : "Ei riittävästi vapaata tilaa tiedoston lähettämiseksi",
     "You are not allowed to share files" : "Sinulla ei ole oikeutta jakaa tiedostoja",
     "You cannot send messages to this conversation at the moment" : "Et voi lähettää viestejä tähän keskusteluun tällä hetkellä",
-    "Code block copied to clipboard" : "Koodilohko kopioitu leikepöydälle",
-    "Code block could not be copied" : "Koodilohkoa ei voitu kopioida",
-    "Copy code block" : "Kopioi koodilohko",
     "Poll" : "Kysely",
     "See results" : "Näytä tulokset",
+    "Reactions" : "Reaktiot",
     "No permission to post reactions in this conversation" : "Ei oikeutta lähettää reaktioita tähän keskusteluun",
     "Show all reactions" : "Näytä kaikki reaktiot",
     "Add more reactions" : "Lisää enemmän reaktioita",
-    "Reactions" : "Reaktiot",
-    "Today" : "Tänään",
-    "Yesterday" : "Eilen",
-    "A week ago" : "Viikko sitten",
-    "_%n day ago_::_%n days ago_" : ["%n päivä sitten","%n päivää sitten"],
+    "Show or collapse system messages" : "Näytä tai piilota järjestelmäviestit",
     "No messages" : "Ei viestejä",
     "All messages have expired or have been deleted." : "Kaikki viestit ovat vanhentuneet tai ne on poistettu.",
     "Cancel search" : "Peruuta haku",
@@ -1017,8 +1015,6 @@ OC.L10N.register(
     "Submit vote" : "Lähetä ääni",
     "Change your vote" : "Muuta antamaasi ääntä",
     "End poll" : "Lopeta kysely",
-    "The message has expired or has been deleted" : "Tämä viesti on vanhentunut tai se on poistettu",
-    "Cancel quote" : "Peruuta lainaus",
     "Send a message to \"{roomName}\"" : "Lähetä viesti huoneeseen \"{roomName}\"",
     "Hide list of participants" : "Piilota osallistujaluettelo",
     "Show list of participants" : "Näytä osallistujaluettelo",
@@ -1102,36 +1098,26 @@ OC.L10N.register(
     "Display name: {name}" : "Näyttönimi: {name}",
     "Edit display name" : "Muokkaa näyttönimeä",
     "Save name" : "Tallenna nimi",
-    "Choose the folder in which attachments should be saved." : "Valitse mihin kansioon liitteet tulee tallentaa.",
     "Select location for attachments" : "Valitse sijainti liitteille",
     "Error while setting attachment folder" : "Virhe asettaessa liitekansiota",
     "Your privacy setting has been saved" : "Yksityisyysasetuksesi on tallennettu",
     "Failed to save sounds setting" : "Ääniasetusten tallentaminen epäonnistui",
     "Sounds setting saved" : "Ääniasetukset tallennettu",
     "Error while saving sounds setting" : "Virhe ääniasetuksia tallentaessa",
-    "Attachments folder" : "Liitteiden kansio",
-    "Browse …" : "Selaa…",
-    "Appearance" : "Ulkoasu",
-    "Privacy" : "Yksityisyys",
-    "Share my read-status and show the read-status of others" : "Jaa lukukuittaukseni ja näytä muiden lukukuittaukset",
-    "Sounds" : "Äänet",
     "Play sounds when participants join or leave a call" : "Toista ääni kun osallistuja liittyy tai poistuu puhelusta",
-    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Keskustelu- ja puheluilmoitusten ääniä voi muuttaa henkilökohtaisisten asetusten kautta.",
-    "Performance" : "Suorituskyky",
-    "Keyboard shortcuts" : "Pikanäppäimet",
-    "Speed up your Talk experience with these quick shortcuts." : "Nopeuta Talk-kokemusta näillä pikanäppäimillä.",
+    "Notification settings" : "Ilmoitusasetukset",
+    "Privacy" : "Yksityisyys",
+    "Attachments folder" : "Liitteiden kansio",
+    "Toggle full screen" : "Koko näyttö päälle/pois",
+    "Search" : "Etsi",
     "Focus the chat input" : "Kohdista keskustelun syötteeseen",
     "Unfocus the chat input to use shortcuts" : "Poista kohdistus keskustelusta käyttääksesi pikanäppäimiä",
     "Edit your last message" : "Muokkaa viimeistä viestiäsi",
-    "Fullscreen the chat or call" : "Keskustelu tai puhelu koko näyttöön",
-    "Search" : "Etsi",
     "Shortcuts while in a call" : "Pikanäppäimet puhelun aikana",
     "Camera on and off" : "Kamera päälle tai pois päältä",
     "Microphone on and off" : "Mikrofoni päälle tai pois päältä",
-    "Space bar" : "Välilyönti",
-    "Push to talk or push to mute" : "Paina puhuaksesi tai mykistääksesi",
     "Raise or lower hand" : "Nosta tai laske käsi",
-    "More actions" : "Lisää toimintoja",
+    "Push to talk or push to mute" : "Paina puhuaksesi tai mykistääksesi",
     "Start call silently" : "Aloita puhelu hiljennettynä",
     "Start call" : "Aloita puhelu",
     "End call" : "Lopeta puhelu",
@@ -1140,7 +1126,6 @@ OC.L10N.register(
     "Stop recording" : "Lopeta tallennus",
     "Send a reaction" : "Lähetä reaktio",
     "React with {reaction}" : "Reagoi käyttäen {reaction}",
-    "Default" : "Oletus",
     "_%n participant in call_::_%n participants in call_" : ["%n osallistuja puhelussa","%n osallistujaa puhelussa"],
     "You are not allowed to enable screensharing" : "Sinulla ei ole oikeutta ottaa näytönjakamista käyttöön",
     "No screensharing" : "Ei näytönjakamista",
@@ -1158,16 +1143,12 @@ OC.L10N.register(
     "Screen sharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
     "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
-    "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea.",
     "An error occurred while starting screensharing." : "Virhe aloitettaessa näytön jakamista.",
     "Show your screen" : "Näytä oma näyttösi",
     "Stop screensharing" : "Lopeta näytön jakaminen",
     "Mute others" : "Mykistä muut",
     "Start recording" : "Käynnistä tallennus",
     "Set up breakout rooms" : "Määritä pienryhmätilat",
-    "Toggle full screen" : "Koko näyttö päälle/pois",
     "Remove participant {name}" : "Poista osallistuja {name}",
     "Open dialpad" : "Avaa numeronäppäimistö",
     "Select a region" : "Valitse alue",
@@ -1231,6 +1212,7 @@ OC.L10N.register(
     "Show all call recordings" : "Näytä kaikki puhelutallenteet",
     "Show all audio" : "Näytä kaikki ääni",
     "Show all other" : "Näytä kaikki muu",
+    "Default" : "Oletus",
     "Group" : "Ryhmä",
     "Team" : "Tiimi",
     "You reconnected to the call" : "Yhdistit uudelleen puheluun",
@@ -1238,7 +1220,6 @@ OC.L10N.register(
     "You added {user0} and {user1}" : "Lisäsit käyttäjät {user0} ja {user1}",
     "{user0} and {user1} joined the call" : "{user0} ja {user1} liittyivät puheluun",
     "You: {lastMessage}" : "Sinä: {lastMessage}",
-    "(edited)" : "(muokattu)",
     "(edited by you)" : "(muokattu toimestasi)",
     "(edited by a deleted user)" : "(muokattu poistetun käyttäjän toimesta)",
     "Leave this page" : "Poistu tältä sivulta",
@@ -1299,16 +1280,11 @@ OC.L10N.register(
     "Reports" : "Raportit",
     "Call summary" : "Puhelun yhteenveto",
     "Call summary - {title}" : "Puhelun yhteenveto - {title}",
-    "You tried to call {user}" : "Yritit soittaa käyttäjälle {user}",
     "%s invited you to a conversation." : "%s kutsui sinut keskusteluun.",
     "You were invited to a conversation." : "Sinut kutsuttiin keskusteluun.",
     "Click the button below to join." : "Napsauta alla olevaa painiketta liittyäksesi.",
     "Join »%s«" : "Liity »%s«",
-    "{user} invited you to a private conversation" : "{user} kutsui sinut yksityiskeskusteluun",
     "Always show the device preview screen before joining a call in this conversation." : "Näytä aina laitteen esikatselunäkymä ennen liittymistä puheluun tässä keskustelussa.",
-    "Copy conversation link" : "Kopioi keskustelulinkki",
-    "Filter unread mentions" : "Suodata lukemattomat maininnat",
-    "Filter unread messages" : "Suodata lukemattomat viestit",
     "Refresh devices list" : "Päivitä laitelista",
     "Media settings" : "Media-asetukset",
     "Always show preview for this conversation" : "Näytä aina esikatselu tälle keskustelulle",
@@ -1316,12 +1292,28 @@ OC.L10N.register(
     "The conversation participants will not be notified about this call" : "Keskustelun osallistujille ei ilmoiteta tästä puhelusta",
     "Normal call" : "Normaali puhelu",
     "The conversation participants will be notified about this call" : "Keskustelun osallistujille ilmoitetaan tästä puhelusta",
-    "Close" : "Sulje",
+    "Code block copied to clipboard" : "Koodilohko kopioitu leikepöydälle",
+    "Code block could not be copied" : "Koodilohkoa ei voitu kopioida",
+    "Copy code block" : "Kopioi koodilohko",
+    "Today" : "Tänään",
+    "Yesterday" : "Eilen",
+    "A week ago" : "Viikko sitten",
+    "_%n day ago_::_%n days ago_" : ["%n päivä sitten","%n päivää sitten"],
+    "Choose the folder in which attachments should be saved." : "Valitse mihin kansioon liitteet tulee tallentaa.",
     "Choose devices" : "Valitse laitteet",
+    "Browse …" : "Selaa…",
+    "Appearance" : "Ulkoasu",
+    "Share my read-status and show the read-status of others" : "Jaa lukukuittaukseni ja näytä muiden lukukuittaukset",
+    "Sounds" : "Äänet",
+    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Keskustelu- ja puheluilmoitusten ääniä voi muuttaa henkilökohtaisisten asetusten kautta.",
+    "Performance" : "Suorituskyky",
+    "Keyboard shortcuts" : "Pikanäppäimet",
+    "Speed up your Talk experience with these quick shortcuts." : "Nopeuta Talk-kokemusta näillä pikanäppäimillä.",
+    "Fullscreen the chat or call" : "Keskustelu tai puhelu koko näyttöön",
+    "Space bar" : "Välilyönti",
     "Blur background" : "Sumenna tausta",
-    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk päivitettiin, lataa sivu uudelleen",
-    "An error happened when trying to share your file" : "Virhe yrittäessä jakaa tiedostoasi",
-    "Failed to join the conversation. Try to reload the page." : "Liittyminen keskusteluun epäonnistui. Päivitä sivu.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud on huoltotilassa, päivitä sivu"
+    "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
+    "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea."
 },
 "nplurals=2; plural=(n != 1);");
