@@ -553,6 +553,7 @@ OC.L10N.register(
     "Blocked" : "Blokiran",
     "Active" : "Aktivan",
     "Expired" : "Istekao",
+    "Never" : "Nikad",
     "The trial could not be requested. Please try again later." : "Nije moguće zatražiti probni rad. Pokušajte ponovo kasnije.",
     "The account could not be deleted. Please try again later." : "Nije moguće izbrisati račun. Pokušajte ponovo kasnije.",
     "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Naš partner Struktur AG pruža uslugu putem koje možete zatražiti signalni poslužitelj. Trebate ispuniti obrazac u nastavku i vaš će Nextcloud zatražiti signalni poslužitelj. Vjerodajnice se automatski popunjavaju nakon postavljanja poslužitelja. Time ćete prebrisati postavke postojećeg signalnog poslužitelja.",
@@ -567,6 +568,8 @@ OC.L10N.register(
     "Created at" : "Stvoreno",
     "Expires at" : "Istječe u",
     "Limits" : "Ograničenja",
+    "Yes" : "Da",
+    "No" : "Ne",
     "Delete the signaling server account" : "Brisanje računa signalnog poslužitelja",
     "_%n user_::_%n users_" : ["%n korisnik","%n korisnika","%n korisnika"],
     "Installed version: {version}" : "Instalirana inačica: {version}",
@@ -607,8 +610,8 @@ OC.L10N.register(
     "OK" : "U redu",
     "Confirm" : "Potvrdi",
     "Reset" : "Resetiraj",
-    "Back" : "Natrag",
     "Cancel" : "Odustani",
+    "Back" : "Natrag",
     "Add participant \"{user}\"" : "Dodaj sudionika „{user}”",
     "Loading …" : "Učitavanje…",
     "From" : "Od",
@@ -685,20 +688,18 @@ OC.L10N.register(
     "Personal" : "Osobno",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zona opasnosti",
+    "Leave conversation" : "Napusti razgovor",
+    "Delete conversation" : "Izbriši razgovor",
     "Do you really want to delete \"{displayName}\"?" : "Želite li zaista izbrisati „{displayName}“?",
-    "Do you really want to delete all messages in \"{displayName}\"?" : "Želite li zaista izbrisati sve poruke u „{displayName}“?",
     "Error while deleting conversation" : "Pogreška pri brisanju razgovora",
+    "Delete all chat messages" : "Izbriši sve razmijenjene poruke",
+    "Do you really want to delete all messages in \"{displayName}\"?" : "Želite li zaista izbrisati sve poruke u „{displayName}“?",
     "Error while clearing chat history" : "Pogreška pri brisanju povijesti razmjene poruka",
     "Be careful, these actions cannot be undone." : "Pažljivo nastavite jer ove radnje nije moguće poništiti.",
-    "Leave conversation" : "Napusti razgovor",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Nakon izlaska iz razgovora za ponovni pristup zatvorenom razgovoru potreban je poziv. Otvorenom razgovoru možete se ponovno pridružiti u bilo kojem trenutku.",
-    "No" : "Ne",
-    "Yes" : "Da",
-    "Delete conversation" : "Izbriši razgovor",
     "Permanently delete this conversation." : "Trajno izbrišite ovaj razgovor.",
     "Delete chat messages" : "Izbriši razmijenjene poruke",
     "Permanently delete all the messages in this conversation." : "Trajno izbrišite sve poruke u ovom razgovoru.",
-    "Delete all chat messages" : "Izbriši sve razmijenjene poruke",
     "Password protection" : "Zaštita zaporkom",
     "Set a password" : "Postavi zaporku",
     "Save password" : "Spremi zaporku",
@@ -745,6 +746,7 @@ OC.L10N.register(
     "Add to favorites" : "Dodaj u favorite",
     "You need to promote a new moderator before you can leave the conversation." : "Morate odabrati novog moderatora prije nego što napustite razgovor.",
     "Conversation actions" : "Radnje razgovora",
+    "Home" : "Doma",
     "No matches found" : "Nema pronađenih podudaranja",
     "No conversations found" : "Nije pronađen nijedan razgovor",
     "An error occurred while performing the search" : "Došlo je do pogreške pri pretraživanju",
@@ -777,14 +779,8 @@ OC.L10N.register(
     "Invalid path selected" : "Odabran nevažeći put",
     "Upload" : "Otpremi",
     "Files" : "Datoteke",
-    "Message read by everyone who shares their reading status" : "Poruku je pročitao svatko tko dijeli status čitanja",
-    "Message sent" : "Poruka poslana",
-    "Deleting message" : "Brisanje poruke",
-    "Message deleted successfully" : "Poruka je uspješno izbrisana",
-    "Message could not be deleted because it is too old" : "Poruku nije moguće izbrisati jer je prestara",
-    "Only normal chat messages can be deleted" : "Mogu se izbrisati samo uobičajene razmijenjene poruke",
-    "An error occurred while deleting the message" : "Došlo je do pogreške pri brisanju poruke",
     "Reply" : "Odgovori",
+    "More actions" : "Dodatne radnje",
     "Reply privately" : "Odgovori privatno",
     "Copy message link" : "Kopiraj poveznicu poruke",
     "Go to file" : "Idi na datoteku",
@@ -795,6 +791,13 @@ OC.L10N.register(
     "The message has been forwarded to {selectedConversationName}" : "Poruka je proslijeđena u {selectedConversationName}",
     "Dismiss" : "Zanemari",
     "Go to conversation" : "Idi na razgovor",
+    "Message read by everyone who shares their reading status" : "Poruku je pročitao svatko tko dijeli status čitanja",
+    "Message sent" : "Poruka poslana",
+    "Deleting message" : "Brisanje poruke",
+    "Message deleted successfully" : "Poruka je uspješno izbrisana",
+    "Message could not be deleted because it is too old" : "Poruku nije moguće izbrisati jer je prestara",
+    "Only normal chat messages can be deleted" : "Mogu se izbrisati samo uobičajene razmijenjene poruke",
+    "An error occurred while deleting the message" : "Došlo je do pogreške pri brisanju poruke",
     "Your browser does not support playing audio files" : "Vaš preglednik ne podržava reprodukciju zvučnih datoteka",
     "Contact" : "Kontakt",
     "{stack} in {board}" : "{stack} u {board}",
@@ -806,10 +809,6 @@ OC.L10N.register(
     "Not enough free space to upload file" : "Nema dovoljno slobodnog prostora za otpremanje datoteke",
     "You are not allowed to share files" : "Nije vam dopušteno dijeliti datoteke",
     "You cannot send messages to this conversation at the moment" : "Trenutno ne možete slati poruke u ovaj razgovor",
-    "Today" : "Danas",
-    "Yesterday" : "Jučer",
-    "_%n day ago_::_%n days ago_" : ["Prije %n dana","Prije %n dana","Prije %n dana"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "Nema poruka",
     "Create a new group conversation" : "Stvori novi grupni razgovor",
     "Add participants" : "Dodaj sudionike",
@@ -893,7 +892,6 @@ OC.L10N.register(
     "Link to a conversation" : "Poveznica za sudjelovanje u razgovoru",
     "Search conversations or users" : "Pretraži razgovore ili korisnike",
     "Select conversation" : "Odaberi razgovor",
-    "Choose the folder in which attachments should be saved." : "Odaberite mapu za spremanje privitaka.",
     "Select location for attachments" : "Odaberite lokaciju privitaka",
     "Error while setting attachment folder" : "Pogreška pri postavljanju mape za privitke",
     "Your privacy setting has been saved" : "Postavka privatnosti je spremljena",
@@ -901,29 +899,20 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Spremanje postavki zvukova nije uspjelo",
     "Sounds setting saved" : "Postavka zvukova je spremljena",
     "Error while saving sounds setting" : "Pogreška pri spremanju postavke zvukova",
-    "Attachments folder" : "Mapa s privicima",
-    "Appearance" : "Izgled",
-    "Privacy" : "Privatnost",
-    "Share my read-status and show the read-status of others" : "Dijeli moj status čitanja i prikaži statuse čitanja drugih sudionika",
-    "Sounds" : "Zvuci",
     "Play sounds when participants join or leave a call" : "Reproduciraj zvukove kad se sudionici pridruže ili napuste poziv",
-    "Performance" : "Učinkovitost",
-    "Keyboard shortcuts" : "Tipkovni prečaci",
-    "Speed up your Talk experience with these quick shortcuts." : "Ubrzajte korištenje aplikacije Talk s pomoću ovih brzih prečaca.",
+    "Notification settings" : "Postavke obavijesti",
+    "Privacy" : "Privatnost",
+    "Attachments folder" : "Mapa s privicima",
+    "Search" : "Traži",
     "Focus the chat input" : "Fokusirajte ulazne poruke",
     "Unfocus the chat input to use shortcuts" : "Odfokusirajte ulazne poruke kako biste iskoristili prečace",
-    "Fullscreen the chat or call" : "Razmjena poruka ili poziv preko cijelog zaslona",
-    "Search" : "Traži",
     "Shortcuts while in a call" : "Prečaci tijekom poziva",
     "Microphone on and off" : "Mikrofon uključen i isključen",
-    "Space bar" : "Razmaknica",
-    "Push to talk or push to mute" : "Pritisni za govor ili pritisni za utišavanje",
     "Raise or lower hand" : "Podigni ili spusti ruku",
-    "More actions" : "Dodatne radnje",
+    "Push to talk or push to mute" : "Pritisni za govor ili pritisni za utišavanje",
     "Start call" : "Uputi poziv",
     "You will be able to join the call only after a moderator starts it." : "Pozivu ćete se moći pridružiti tek nakon što ga moderator pokrene.",
     "Recording" : "Snimanje",
-    "Default" : "Zadano",
     "You are not allowed to enable screensharing" : "Nije vam dopušteno omogućiti dijeljenje zaslona",
     "No screensharing" : "Nema dijeljenja zaslona",
     "Screensharing options" : "Mogućnosti dijeljenja zaslona",
@@ -949,9 +938,6 @@ OC.L10N.register(
     "Screen sharing is not supported by your browser." : "Vaš preglednik ne podržava dijeljenje zaslona.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Dijeljenje zaslona zahtijeva učitavanje stranice putem HTTPS-a.",
     "Screensharing requires the page to be loaded through HTTPS." : "Dijeljenje zaslona zahtijeva učitavanje stranice putem HTTPS-a.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Dijeljenje zaslona moguće je samo u pregledniku Firefox, inačice 52 ili novije.",
-    "Screensharing extension is required to share your screen." : "Za dijeljenje zaslona potrebno je instalirati proširenje za dijeljenje zaslona.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Koristite se nekim drugim preglednikom za dijeljenje zaslona, primjerice preglednikom Firefox ili Chrome.",
     "An error occurred while starting screensharing." : "Došlo je do pogreške pri pokretanju dijeljenja zaslona.",
     "Show your screen" : "Pokaži svoj zaslon",
     "Stop screensharing" : "Prekini dijeljenje zaslona",
@@ -959,6 +945,7 @@ OC.L10N.register(
     "Select a region" : "Odaberite regiju",
     "Submit" : "Šalji",
     "Search …" : "Traži …",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Poruka bez spominjanja",
     "Mention myself" : "Spomeni sebe",
     "The conversation does not exist" : "Razgovor ne postoji",
@@ -1014,6 +1001,7 @@ OC.L10N.register(
     "Audio" : "Audio",
     "Other" : "Drugo",
     "Show all files" : "Prikaži sve datoteke",
+    "Default" : "Zadano",
     "Group" : "Grupa",
     "You: {lastMessage}" : "Vi: {lastMessage}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Pokušavate se pridružiti razgovoru dok imate otvorenu sesiju u drugom prozoru ili na drugom uređaju. Nextcloud Talk trenutačno ne podržava tu radnju. Što želite učiniti?",
@@ -1065,22 +1053,27 @@ OC.L10N.register(
     "__language_name__" : "Hrvatski",
     "Tasks" : "Zadaci",
     "Notes" : "Bilješke",
-    "You tried to call {user}" : "Pokušali ste nazvati {user}",
     "%s invited you to a conversation." : "%s vas je pozvao u razgovor.",
     "You were invited to a conversation." : "Pozvani ste u razgovor.",
     "Click the button below to join." : "Kliknite gumb ispod za pridruživanje.",
     "Join »%s«" : "Pridruži se »%s«",
-    "{user} invited you to a private conversation" : "{user} vas je pozvao u privatni razgovor",
     "Always show the device preview screen before joining a call in this conversation." : "Uvijek prikažite zaslon za pretpregled uređaja prije pridruživanja pozivu u ovom razgovoru.",
-    "Copy conversation link" : "Kopiraj poveznicu za razgovor",
-    "Close" : "Zatvori",
+    "Today" : "Danas",
+    "Yesterday" : "Jučer",
+    "_%n day ago_::_%n days ago_" : ["Prije %n dana","Prije %n dana","Prije %n dana"],
+    "Choose the folder in which attachments should be saved." : "Odaberite mapu za spremanje privitaka.",
     "Choose devices" : "Odaberi uređaje",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu prije upućivanja ili pridruživanja razgovoru.",
+    "Appearance" : "Izgled",
+    "Share my read-status and show the read-status of others" : "Dijeli moj status čitanja i prikaži statuse čitanja drugih sudionika",
+    "Sounds" : "Zvuci",
+    "Performance" : "Učinkovitost",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
+    "Speed up your Talk experience with these quick shortcuts." : "Ubrzajte korištenje aplikacije Talk s pomoću ovih brzih prečaca.",
+    "Fullscreen the chat or call" : "Razmjena poruka ili poziv preko cijelog zaslona",
+    "Space bar" : "Razmaknica",
     "Blur background" : "Zamuti pozadinu",
-    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu",
-    "An error happened when trying to share your file" : "Došlo je do pogreške pri pokušaju dijeljenja datoteke",
-    "Failed to join the conversation. Try to reload the page." : "Pridruživanje razgovoru nije uspjelo. Pokušajte ponovno učitati stranicu.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud je u načinu održavanja, ponovno učitajte stranicu",
-    "Lost connection to signaling server. Try to reload the page manually." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušajte ponovno učitati stranicu."
+    "Sharing your screen only works with Firefox version 52 or newer." : "Dijeljenje zaslona moguće je samo u pregledniku Firefox, inačice 52 ili novije.",
+    "Screensharing extension is required to share your screen." : "Za dijeljenje zaslona potrebno je instalirati proširenje za dijeljenje zaslona.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Koristite se nekim drugim preglednikom za dijeljenje zaslona, primjerice preglednikom Firefox ili Chrome."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
