@@ -545,6 +545,7 @@ OC.L10N.register(
     "Blocked" : "Blocat",
     "Active" : "Activa",
     "Expired" : "Expirat",
+    "Never" : "Jamai",
     "URL of this Nextcloud instance" : "URL d’aquesta instància Nextcloud",
     "Email of the user" : "Email de l’utilizaire",
     "Language" : "Lenga",
@@ -553,6 +554,8 @@ OC.L10N.register(
     "Created at" : "Creat lo",
     "Expires at" : "Expira lo",
     "Limits" : "Limits",
+    "Yes" : "Òc",
+    "No" : "Non",
     "_%n user_::_%n users_" : ["%n utilizaire","%n utilizaires"],
     "Installed version: {version}" : "Version installada : {version}",
     "Downloading …" : "Telecargament…",
@@ -585,8 +588,8 @@ OC.L10N.register(
     "Web server setup checks" : "Verificacions de configuracion del servidor Web",
     "Confirm" : "Confirmar",
     "Reset" : "Reïnicializar",
-    "Back" : "Retorn",
     "Cancel" : "Anullar",
+    "Back" : "Retorn",
     "Add participant \"{user}\"" : "Apondre participant « {user} »",
     "Loading …" : "Cargament…",
     "From" : "De",
@@ -674,20 +677,18 @@ OC.L10N.register(
     "Personal" : "Personal",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zòna perilhosa",
+    "Leave conversation" : "Quitar la conversacion",
+    "Delete conversation" : "Suprimir la conversacion",
     "Do you really want to delete \"{displayName}\"?" : "Volètz vertadièrament suprimir « {displayName} » ?",
-    "Do you really want to delete all messages in \"{displayName}\"?" : "Volètz vertadièrament suprimir totes los messatges dins « {displayName} » ?",
     "Error while deleting conversation" : "Error pendent la supression de la conversacion",
+    "Delete all chat messages" : "Suprimir totes los messatges del chat",
+    "Do you really want to delete all messages in \"{displayName}\"?" : "Volètz vertadièrament suprimir totes los messatges dins « {displayName} » ?",
     "Error while clearing chat history" : "Error pendent l’escafament de l’istoric del chat",
     "Be careful, these actions cannot be undone." : "Fasètz atencion, aquelas accions pòdon pas èsser anulladas.",
-    "Leave conversation" : "Quitar la conversacion",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Un còp quitada, per tornar a un conversacion tampada, cal un convit. Una conversacion dubèrta es totjorn accessibla.",
-    "No" : "Non",
-    "Yes" : "Òc",
-    "Delete conversation" : "Suprimir la conversacion",
     "Permanently delete this conversation." : "Suprimir permanent aquesta conversacion",
     "Delete chat messages" : "Suprimir los messatges del chat",
     "Permanently delete all the messages in this conversation." : "Suprimir per totjorn totes los messatges d’aquesta conversacion.",
-    "Delete all chat messages" : "Suprimir totes los messatges del chat",
     "_%n hour_::_%n hours_" : ["%n ora","%n oras"],
     "_%n day_::_%n days_" : ["%n jorn","%n jorns"],
     "_%n week_::_%n weeks_" : ["%n setmana","%n setmanas"],
@@ -766,16 +767,10 @@ OC.L10N.register(
     "Invalid path selected" : "Camin seleccionat invalid",
     "Upload" : "Cargament",
     "Files" : "Fichièrs",
-    "Message read by everyone who shares their reading status" : "Messatge legit per tot lo monde que partejan lo estatut de lectura",
-    "Message sent" : "Messatge mandat",
-    "Deleting message" : "Supression del messatge",
-    "Message deleted successfully" : "Messatge corrèctament suprimit",
-    "Message could not be deleted because it is too old" : "Lo messatge a pas pogut èsser suprimit perque es tròp ancian",
-    "Only normal chat messages can be deleted" : "Sonque los messatges de chat normal pòdon èsser suprimits",
-    "An error occurred while deleting the message" : "Error pendent la supression del messatge",
     "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
     "Add a reaction to this message" : "Apondre una reaccion a aqueste messatge",
     "Reply" : "Respondre",
+    "More actions" : "Mai d’accions",
     "Reply privately" : "Respondre en privat",
     "Copy message link" : "Copiar ligam messatge",
     "Go to file" : "Anar al fichièr",
@@ -791,6 +786,13 @@ OC.L10N.register(
     "Go to conversation" : "Anar a la conversacion",
     "Translate message" : "Traduire lo messatge",
     "Translating" : "Traduccion",
+    "Message read by everyone who shares their reading status" : "Messatge legit per tot lo monde que partejan lo estatut de lectura",
+    "Message sent" : "Messatge mandat",
+    "Deleting message" : "Supression del messatge",
+    "Message deleted successfully" : "Messatge corrèctament suprimit",
+    "Message could not be deleted because it is too old" : "Lo messatge a pas pogut èsser suprimit perque es tròp ancian",
+    "Only normal chat messages can be deleted" : "Sonque los messatges de chat normal pòdon èsser suprimits",
+    "An error occurred while deleting the message" : "Error pendent la supression del messatge",
     "Your browser does not support playing audio files" : "Vòstre navegador pren pas en carga la lectura dels fichièrs àudio",
     "Contact" : "Contacte",
     "{stack} in {board}" : "{stack} dins {board}",
@@ -806,10 +808,6 @@ OC.L10N.register(
     "Poll • Ended" : "Sondatge・Terminat",
     "Poll" : "Sondatge",
     "See results" : "Veire los resultats",
-    "Today" : "Uèi",
-    "Yesterday" : "Ièr",
-    "_%n day ago_::_%n days ago_" : ["fa %n jorn","fa %n jorns"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "Cap de messatge",
     "Cancel search" : "Anullar la recèrca",
     "Add a phone number" : "Apondre un numèro de telefòn",
@@ -917,7 +915,6 @@ OC.L10N.register(
     "Phone numbers" : "Numèros de telefòn",
     "Display name: {name}" : "Nom d’afichatge : {name}",
     "Save name" : "Enregistrar lo nom",
-    "Choose the folder in which attachments should be saved." : "Causir lo dossièr ont seràn gardadas las pèça juntas.",
     "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
     "Error while setting attachment folder" : "Error pendent la definicion del dossièr de pèça junta",
     "Your privacy setting has been saved" : "Paramètre de confidencialitat enregistrat",
@@ -925,22 +922,17 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Cargament impossible del paramètre de son",
     "Sounds setting saved" : "Paramètres de son enregistrats",
     "Error while saving sounds setting" : "Error en enregistrant lo paramètre de son",
-    "Attachments folder" : "Dossièr de pèças-juntas",
-    "Browse …" : "Percórrer...",
-    "Privacy" : "Confidencialitat",
-    "Sounds" : "Sons",
     "Play sounds when participants join or leave a call" : "Emetre sons quand los participants rejonhon o quitan una sonada",
-    "Keyboard shortcuts" : "Acorchis de clavièr",
-    "Speed up your Talk experience with these quick shortcuts." : "Acceleratz vòstra experiéncia Talk amb aqueles acorchis.",
-    "Fullscreen the chat or call" : "Passar la messatjariá o la sonada en plen ecran",
+    "Notification settings" : "Paramètres de notificacions",
+    "Privacy" : "Confidencialitat",
+    "Attachments folder" : "Dossièr de pèças-juntas",
+    "Toggle full screen" : "Alternar ecran complèt",
     "Search" : "Search",
     "Shortcuts while in a call" : "Acorchis pendent una sonada",
     "Camera on and off" : "Vidèo activada/desactivada",
     "Microphone on and off" : "Microfòn activat/desactivat",
-    "Space bar" : "barra d’espaci",
-    "Push to talk or push to mute" : "Tocar per parlar o tocar per copar lo son",
     "Raise or lower hand" : "Levar o baissar la man",
-    "More actions" : "Mai d’accions",
+    "Push to talk or push to mute" : "Tocar per parlar o tocar per copar lo son",
     "Start call silently" : "Començar la sonada en silenci",
     "Start call" : "Començar sonada",
     "End call" : "Acabar la sonada",
@@ -951,7 +943,6 @@ OC.L10N.register(
     "Stop recording" : "Arrestar l'enregistrament",
     "Send a reaction" : "Enviar una reaccion",
     "React with {reaction}" : "Reagir amb {reaction}",
-    "Default" : "Defaut",
     "You are not allowed to enable screensharing" : "Avètz pas l'autorizacion per activar lo partiment d’ecran",
     "No screensharing" : "Cap de partiment d’ecran",
     "Screensharing options" : "Opcion de partiment d’ecran",
@@ -973,18 +964,15 @@ OC.L10N.register(
     "Screen sharing is not supported by your browser." : "Vòstre navegador pren pas en carga lo partiment d’ecran.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís que la pagina siá cargada via HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís un cargament via HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Lo partiment d’ecran fonciona pas qu’amb Firefox 52 o mai recent.",
-    "Screensharing extension is required to share your screen." : "Una extension de partiment d’ecran es requerida per partejar l’ecran.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Volgatz utilizar un navegador diferent coma Firefox o Chrome per partejar l’ecran.",
     "An error occurred while starting screensharing." : "S’es producha una error en aviant lo partiment d’ecran.",
     "Show your screen" : "Partejar l’ecran",
     "Stop screensharing" : "Arrestar partiment d’ecran",
     "Mute others" : "Copar lo son dels autres",
     "Start recording" : "Lançar l'enregistrament",
-    "Toggle full screen" : "Alternar ecran complèt",
     "Select a region" : "Seleccionatz una region",
     "Submit" : "Transmetre",
     "Search …" : "Recercar...",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Messatge sens mencion",
     "Mention myself" : "Me mencionar",
     "The conversation does not exist" : "La conversacion existís pas",
@@ -1048,6 +1036,7 @@ OC.L10N.register(
     "Show all call recordings" : "Mostrar los enregistraments de sonadas",
     "Show all audio" : "Veire totes los àudios",
     "Show all other" : "Veire tota la rèsta",
+    "Default" : "Defaut",
     "Group" : "Grop",
     "You: {lastMessage}" : "Vos : {lastMessage}",
     "Leave this page" : "Quitar aquesta pagina",
@@ -1101,23 +1090,26 @@ OC.L10N.register(
     "iOS app" : "Aplicacion iOS",
     "__language_name__" : "Occitan",
     "Tasks" : "Prètzfaches",
-    "You tried to call {user}" : "Avètz ensajat de sonar {user}",
     "%s invited you to a conversation." : "%s vos a convidat a una conversacion.",
     "You were invited to a conversation." : "Òm vos a convidat a una conversacion.",
     "Click the button below to join." : "Clicatz sul boton per participar.",
     "Join »%s«" : "Rejónher « %s »",
-    "{user} invited you to a private conversation" : "{user} vos a convidat a una conversacion privada",
     "Always show the device preview screen before joining a call in this conversation." : "Totjorn mostrar l’ecran d’apercebut abans de rejónher una sonada d’aquesta conversacion.",
-    "Copy conversation link" : "Copiar lo ligam de conversacion",
     "Media settings" : "Paramètres dels mèdias",
-    "Close" : "Tampar",
+    "Today" : "Uèi",
+    "Yesterday" : "Ièr",
+    "_%n day ago_::_%n days ago_" : ["fa %n jorn","fa %n jorns"],
+    "Choose the folder in which attachments should be saved." : "Causir lo dossièr ont seràn gardadas las pèça juntas.",
     "Choose devices" : "Causir periferics",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada.",
+    "Browse …" : "Percórrer...",
+    "Sounds" : "Sons",
+    "Keyboard shortcuts" : "Acorchis de clavièr",
+    "Speed up your Talk experience with these quick shortcuts." : "Acceleratz vòstra experiéncia Talk amb aqueles acorchis.",
+    "Fullscreen the chat or call" : "Passar la messatjariá o la sonada en plen ecran",
+    "Space bar" : "barra d’espaci",
     "Blur background" : "Rèireplan trebol",
-    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk foguèt mes a jorn, mercés de tornar cargar la pagina",
-    "An error happened when trying to share your file" : "Una error s’es producha en ensajant de partejar vòstre fichièr",
-    "Failed to join the conversation. Try to reload the page." : "Impossible de rejónher la conversacion. Ensajatz de recargar la pagina.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud es en mòde manteniment, volgatz recargar la pagina",
-    "Lost connection to signaling server. Try to reload the page manually." : "Connexion perduda al servidor de senhalament. Ensajatz de recargar la pagina manualament."
+    "Sharing your screen only works with Firefox version 52 or newer." : "Lo partiment d’ecran fonciona pas qu’amb Firefox 52 o mai recent.",
+    "Screensharing extension is required to share your screen." : "Una extension de partiment d’ecran es requerida per partejar l’ecran.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Volgatz utilizar un navegador diferent coma Firefox o Chrome per partejar l’ecran."
 },
 "nplurals=2; plural=(n > 1);");
