@@ -472,10 +472,13 @@ OC.L10N.register(
     "Error" : "Eroare",
     "Blocked" : "Blocat",
     "Active" : "Activ",
+    "Never" : "Niciodată",
     "Language" : "Limba",
     "Country" : "Țară",
     "Status" : "Stare",
     "Created at" : "Creat la",
+    "Yes" : "Da",
+    "No" : "Nu",
     "Downloading …" : "Se descarcă ...",
     "Failed" : "Eșuat",
     "OK" : "OK",
@@ -485,10 +488,10 @@ OC.L10N.register(
     "Allow participants to choose" : "Permite participanților să aleagă",
     "Confirm" : "Confirmă",
     "Reset" : "Resetare",
+    "Cancel" : "Anulare",
     "Unassigned participants" : "Participanți neasociați",
     "Back" : "Înapoi",
     "Assign" : "Atribuie",
-    "Cancel" : "Anulare",
     "Add participant \"{user}\"" : "Adaugă participant \"{user}\"",
     "Now" : "Acum",
     "From" : "De la",
@@ -575,19 +578,17 @@ OC.L10N.register(
     "Basic Info" : "Informații de bază",
     "Personal" : "Personal",
     "Moderation" : "Moderare",
-    "Do you really want to delete \"{displayName}\"?" : "Sigur ștergeți \"{displayName}\"?",
-    "Do you really want to delete all messages in \"{displayName}\"?" : "Sigur ștergeți toate mesajele din \"{displayName}\"?",
-    "Error while deleting conversation" : "Eroare la ștergerea conversației",
-    "Error while clearing chat history" : "Eroare la ștergerea istoricului de chat",
     "Leave conversation" : "Părăsiți conversația",
-    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Odată ce ați părăsit o conversație, pentru a vă realătura aveți nevoie de o invitație. Conversațiile deschise pot fi accesate oricând.",
-    "No" : "Nu",
-    "Yes" : "Da",
     "Delete conversation" : "Șterge conversația",
+    "Do you really want to delete \"{displayName}\"?" : "Sigur ștergeți \"{displayName}\"?",
+    "Error while deleting conversation" : "Eroare la ștergerea conversației",
+    "Delete all chat messages" : "Șterge toate mesajele de chat",
+    "Do you really want to delete all messages in \"{displayName}\"?" : "Sigur ștergeți toate mesajele din \"{displayName}\"?",
+    "Error while clearing chat history" : "Eroare la ștergerea istoricului de chat",
+    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Odată ce ați părăsit o conversație, pentru a vă realătura aveți nevoie de o invitație. Conversațiile deschise pot fi accesate oricând.",
     "Permanently delete this conversation." : "Șterge permanent conversația",
     "Delete chat messages" : "Șterge mesajele de chat",
     "Permanently delete all the messages in this conversation." : "Șterge permanent toate mesajele din conversație",
-    "Delete all chat messages" : "Șterge toate mesajele de chat",
     "Message expiration disabled" : "Expirarea mesajului dezactivată",
     "Message expiration set: {duration}" : "Expirarea mesajului la: {duration}",
     "Message expiration" : "Expirare mesaj",
@@ -648,7 +649,6 @@ OC.L10N.register(
     "Blur" : "Blurează",
     "Upload" : "Încărcare",
     "Files" : "Fișiere",
-    "Message sent" : "Mesajul a fost transmis",
     "Later today – {timeLocale}" : "Azi, mai târziu – {timeLocale}",
     "Set reminder for later today" : "Setează memo pentru azi, mai târziu",
     "Tomorrow – {timeLocale}" : "Mâine – {timeLocale}",
@@ -659,16 +659,15 @@ OC.L10N.register(
     "Set reminder for next week" : "Setează memo pentru săptămâna viitoare",
     "Clear reminder – {timeLocale}" : "Șterge memento – {timeLocale}",
     "Reply" : "Răspunde",
+    "More actions" : "Mai multe acțiuni",
     "Set reminder" : "Setează memo",
     "Edit message" : "Editare mesaj",
     "Translate" : "Tradu",
     "Set custom reminder" : "Setează memento particular",
     "Dismiss" : "Elimină",
+    "Message sent" : "Mesajul a fost transmis",
     "Contact" : "Contact",
     "{stack} in {board}" : "{stack} în {board}",
-    "Today" : "Azi",
-    "Yesterday" : "Ieri",
-    "_%n day ago_::_%n days ago_" : ["%n zi în rumă","Acum %n zile","Acum %n zile"],
     "No messages" : "Niciun mesaj",
     "Cancel search" : "Renunță la căutare",
     "All set, the conversation \"{conversationName}\" was created." : "Totul a fost configurat, conversația \"{conversationName}\" a fost creată.",
@@ -739,7 +738,6 @@ OC.L10N.register(
     "Phone numbers" : "Numere de telefon",
     "Display name: {name}" : "Numele afișat: {name}",
     "Save name" : "Salvează numele",
-    "Choose the folder in which attachments should be saved." : "Selectați folderul în care se vor salva atașamentele",
     "Select location for attachments" : "Selectați locația atașamentelor",
     "Error while setting attachment folder" : "Eroare la setarea dosarului pentru atașamente",
     "Your privacy setting has been saved" : "Setările de confidențialitate au fost salvate",
@@ -748,30 +746,19 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Eroare la salvarea setărilor de sunet",
     "Sounds setting saved" : "Setările de sunet au fost salvate",
     "Error while saving sounds setting" : "Eroare la salvarea setărilor de sunet",
-    "Attachments folder" : "Dosarul pentru atașamente",
-    "Browse …" : "Navigare ...",
-    "Appearance" : "Aspect",
-    "Privacy" : "Confidențialitate",
-    "Share my read-status and show the read-status of others" : "Arată statusul meu de citire și pe al celorlalți",
-    "Share my typing-status and show the typing-status of others" : "Arată când tastez eu și ceilalți",
-    "Sounds" : "Sunete",
     "Play sounds when participants join or leave a call" : "Avertizează sonor când cineva se alătură sau părăsește o videoconferință",
-    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Sunetele pentru chat și notificări pot fi selectate în setările personale.",
-    "Performance" : "Performanța",
-    "Blur background image in the call (may increase GPU load)" : "Blurează imaginea de fundal (poate încărca GPU)",
-    "Keyboard shortcuts" : "Scurtături din tastatură",
-    "Speed up your Talk experience with these quick shortcuts." : "Accelerați experiența în Talk cu aceste scurtături rapide",
+    "Notification settings" : "Setări notificări",
+    "Privacy" : "Confidențialitate",
+    "Attachments folder" : "Dosarul pentru atașamente",
+    "Toggle full screen" : "Comută în ecran complet",
+    "Search" : "Caută",
     "Focus the chat input" : "Focalizează inputul în chat",
     "Unfocus the chat input to use shortcuts" : "Defocalizează inputul în chat pentru folosirea scurtăturilor",
-    "Fullscreen the chat or call" : "Trece în ecran complet chatul sau videoconferința",
-    "Search" : "Caută",
     "Shortcuts while in a call" : "Scurtături pentru videoconferință",
     "Camera on and off" : "Activează și dezactivează camera",
     "Microphone on and off" : "Activează și dezactivează microfonul",
-    "Space bar" : "Bara de spațiu",
-    "Push to talk or push to mute" : "Apăsați pentru a vorbi sau pentru a suprima microfonul",
     "Raise or lower hand" : "Ridicare sau coborâre mână",
-    "More actions" : "Mai multe acțiuni",
+    "Push to talk or push to mute" : "Apăsați pentru a vorbi sau pentru a suprima microfonul",
     "Start call silently" : "Pornește videoconferința fără sunet",
     "Start call" : "Pornește videoconferința",
     "End call" : "Închidere videoconferință",
@@ -780,7 +767,6 @@ OC.L10N.register(
     "The call has been running for one hour." : "Videoconferința durează de o oră",
     "Send a reaction" : "Trimite o reacție",
     "React with {reaction}" : "Reacționează cu {reaction}",
-    "Default" : "Implicit",
     "You are not allowed to enable screensharing" : "Nu aveți permisiunea de partajare a ecranului",
     "No screensharing" : "Nicio partajare de ecran",
     "Screensharing options" : "Opțiuni pentru partajarea ecranului",
@@ -795,12 +781,10 @@ OC.L10N.register(
     "Disable background blur" : "Dezactivează blurarea fundalului",
     "Disable screenshare" : "Dezactivează partajarea ecranului",
     "Screen sharing is not supported by your browser." : "Partajarea ecranului nu e posibilă în acest browser.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Folosiți un alt browser precum Firefox și Chrome pentru partajarea ecranului.",
     "An error occurred while starting screensharing." : "Eroare la partajarea ecranului.",
     "Show your screen" : "Prezentați ecranul",
     "Stop screensharing" : "Oprește partajarea ecranului",
     "Mute others" : "Închide microfonul celorlalți",
-    "Toggle full screen" : "Comută în ecran complet",
     "Remove participant {name}" : "Elimină participantul {name}",
     "Keep" : "Păstrare",
     "Select a region" : "Selectează o regiune",
@@ -833,6 +817,7 @@ OC.L10N.register(
     "Show all locations" : "Arată toate locațiile",
     "Show all audio" : "Arată audio",
     "Show all other" : "Arată celelalte",
+    "Default" : "Implicit",
     "Group" : "Grup",
     "Team" : "Echipă",
     "You reconnected to the call" : "V-ați reconectat",
@@ -885,20 +870,29 @@ OC.L10N.register(
     "__language_name__" : "Română",
     "Tasks" : "Sarcini",
     "Notes" : "Notițe",
-    "You tried to call {user}" : "Ați încercat să apelați pe {user}",
     "%s invited you to a conversation." : "%s v-a invitat într-o conversație.",
     "You were invited to a conversation." : "Ați fost invitat într-o conversație.",
     "Click the button below to join." : "Apăsați butonul pentru a vă alătura.",
     "Join »%s«" : "Alăturați-vă »%s«",
-    "{user} invited you to a private conversation" : "{user} v-a invitat într-o conversație privată",
     "Always show the device preview screen before joining a call in this conversation." : "Arată întotdeauna o previzualizare a ecranului dispozitvului înainte de a participa la această conversație.",
-    "Copy conversation link" : "Copiază linkul conversației",
-    "Filter unread mentions" : "Filtrează mențiunile necitite",
-    "Filter unread messages" : "Filtrează mesajele necitite",
-    "Close" : "Închide",
+    "Today" : "Azi",
+    "Yesterday" : "Ieri",
+    "_%n day ago_::_%n days ago_" : ["%n zi în rumă","Acum %n zile","Acum %n zile"],
+    "Choose the folder in which attachments should be saved." : "Selectați folderul în care se vor salva atașamentele",
     "Choose devices" : "Selectați dispozitivele",
+    "Browse …" : "Navigare ...",
+    "Appearance" : "Aspect",
+    "Share my read-status and show the read-status of others" : "Arată statusul meu de citire și pe al celorlalți",
+    "Share my typing-status and show the typing-status of others" : "Arată când tastez eu și ceilalți",
+    "Sounds" : "Sunete",
+    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Sunetele pentru chat și notificări pot fi selectate în setările personale.",
+    "Performance" : "Performanța",
+    "Blur background image in the call (may increase GPU load)" : "Blurează imaginea de fundal (poate încărca GPU)",
+    "Keyboard shortcuts" : "Scurtături din tastatură",
+    "Speed up your Talk experience with these quick shortcuts." : "Accelerați experiența în Talk cu aceste scurtături rapide",
+    "Fullscreen the chat or call" : "Trece în ecran complet chatul sau videoconferința",
+    "Space bar" : "Bara de spațiu",
     "Blur background" : "Blurează fundalul",
-    "An error happened when trying to share your file" : "Eroare la încercarea de partajare a fișierului",
-    "Failed to join the conversation. Try to reload the page." : "Eroare la încercarea de participare la conversație. Încercați să reîncărcați pagina. "
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Folosiți un alt browser precum Firefox și Chrome pentru partajarea ecranului."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
