@@ -12,9 +12,11 @@ use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Files\Util;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Session;
+use OCA\Talk\Model\ThreadAttendee;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
+use OCA\Talk\Service\ThreadService;
 use OCA\Talk\Webinary;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
@@ -42,6 +44,7 @@ class Notifier {
 		private IUserManager $userManager,
 		private IGroupManager $groupManager,
 		private ParticipantService $participantService,
+		private ThreadService $threadService,
 		private IConfig $config,
 		private ITimeFactory $timeFactory,
 		private Util $util,
@@ -66,7 +69,7 @@ class Notifier {
 	 * @return string[] Users that were mentioned
 	 * @psalm-return array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}>
 	 */
-	public function notifyMentionedUsers(Room $chat, IComment $comment, array $alreadyNotifiedUsers, bool $silent, ?Participant $participant = null): array {
+	public function notifyMentionedUsers(Room $chat, IComment $comment, array $alreadyNotifiedUsers, bool $silent, ?Participant $participant = null, ?int $threadId = null): array {
 		$usersToNotify = $this->getUsersToNotify($chat, $comment, $alreadyNotifiedUsers, $participant);
 
 		if (!$usersToNotify) {
@@ -75,7 +78,7 @@ class Notifier {
 
 		$shouldFlush = false;
 		if (!$silent) {
-			$notification = $this->createNotification($chat, $comment, 'mention');
+			$notification = $this->createNotification($chat, $comment, 'mention', threadId: $threadId);
 			$parameters = $notification->getSubjectParameters();
 			$shouldFlush = $this->notificationManager->defer();
 		}
@@ -200,7 +203,7 @@ class Notifier {
 	 * @return array[] Actor that was replied to
 	 * @psalm-return array<int, array{id: string, type: string, reason: string}>
 	 */
-	public function notifyReplyToAuthor(Room $chat, IComment $comment, IComment $replyTo, bool $silent): array {
+	public function notifyReplyToAuthor(Room $chat, IComment $comment, IComment $replyTo, bool $silent, ?int $threadId = null): array {
 		if ($replyTo->getActorType() !== Attendee::ACTOR_USERS && $replyTo->getActorType() !== Attendee::ACTOR_FEDERATED_USERS) {
 			// No reply notification when the replyTo-author was not a user or federated user
 			return [];
@@ -222,7 +225,7 @@ class Notifier {
 		}
 
 		if (!$silent) {
-			$notification = $this->createNotification($chat, $comment, 'reply');
+			$notification = $this->createNotification($chat, $comment, 'reply', threadId: $threadId);
 			$notification->setUser($replyTo->getActorId());
 			$notification->setPriorityNotification($shouldMentionedUserBeNotified === self::PRIORITY_IMPORTANT);
 			$this->notificationManager->notify($notification);
@@ -258,10 +261,41 @@ class Notifier {
 		}
 
 		$participants = $this->participantService->getParticipantsByNotificationLevel($chat, Participant::NOTIFY_ALWAYS);
+		$threadId = (int)$comment->getTopmostParentId();
+		/** @var array<int, ThreadAttendee> $threadAttendees */
+		$threadAttendees = [];
+		if ($threadId !== 0) {
+			$threadAttendees = $this->threadService->findAttendeesForNotificationByThreadId($chat->getId(), $threadId);
+		}
 
-		$notification = $this->createNotification($chat, $comment, 'chat');
+		// Handle participants that only subscribed with Participant::NOTIFY_ALWAYS to the thread, but not the conversation
+		$threadAttendeeIds = array_map(static fn (ThreadAttendee $threadAttendee): int => $threadAttendee->getAttendeeId(),
+			array_filter($threadAttendees, static fn (ThreadAttendee $threadAttendee): bool => $threadAttendee->getNotificationLevel() === Participant::NOTIFY_ALWAYS)
+		);
+		if (!empty($threadAttendeeIds)) {
+			$participantIds = array_map(static fn (Participant $participant): int => $participant->getAttendee()->getId(), $participants);
+			$missingParticipantIds = array_diff($threadAttendeeIds, $participantIds);
+			if (!empty($missingParticipantIds)) {
+				$missingParticipants = $this->participantService->getParticipantsByAttendeeId($chat, $missingParticipantIds);
+				if (!empty($missingParticipants)) {
+					$participants = array_merge($participants, $missingParticipants);
+				}
+			}
+		}
+
+		$notification = $this->createNotification($chat, $comment, 'chat', threadId: $threadId);
 		foreach ($participants as $participant) {
+			$attendeeId = $participant->getAttendee()->getId();
 			$shouldParticipantBeNotified = $this->shouldParticipantBeNotified($participant, $comment, $alreadyNotifiedUsers);
+
+			if (isset($threadAttendees[$attendeeId])) {
+				$threadAttendee = $threadAttendees[$attendeeId];
+				if ($threadAttendee->getNotificationLevel() !== Participant::NOTIFY_ALWAYS) {
+					// User unsubscribed from this thread
+					continue;
+				}
+			}
+
 			if ($shouldParticipantBeNotified === self::PRIORITY_NONE) {
 				continue;
 			}
@@ -600,18 +634,24 @@ class Notifier {
 	 * Creates a notification for the given chat message comment and mentioned
 	 * user ID.
 	 */
-	private function createNotification(Room $chat, IComment $comment, string $subject, array $subjectData = [], ?IComment $reaction = null): INotification {
+	private function createNotification(Room $chat, IComment $comment, string $subject, array $subjectData = [], ?IComment $reaction = null, ?int $threadId = null): INotification {
 		$subjectData['userType'] = $reaction ? $reaction->getActorType() : $comment->getActorType();
 		$subjectData['userId'] = $reaction ? $reaction->getActorId() : $comment->getActorId();
 
+		$messageData = [
+			'commentId' => $comment->getId(),
+		];
+
+		if ($threadId !== null && $threadId !== 0) {
+			$messageData['threadId'] = $threadId;
+		}
+
 		$notification = $this->notificationManager->createNotification();
 		$notification
 			->setApp('spreed')
 			->setObject('chat', $chat->getToken())
 			->setSubject($subject, $subjectData)
-			->setMessage($comment->getVerb(), [
-				'commentId' => $comment->getId(),
-			])
+			->setMessage($comment->getVerb(), $messageData)
 			->setDateTime($reaction ? $reaction->getCreationDateTime() : $comment->getCreationDateTime());
 
 		return $notification;
@@ -647,12 +687,21 @@ class Notifier {
 				$participant = new Participant($room, $attendee, null);
 			}
 
-			if ($room->getLobbyState() !== Webinary::LOBBY_NONE &&
-				!($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
+			if ($room->getLobbyState() !== Webinary::LOBBY_NONE
+				&& !($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
 				return self::PRIORITY_NONE;
 			}
 
 			$notificationLevel = $attendee->getNotificationLevel();
+			$threadId = (int)$comment->getTopmostParentId();
+			if ($threadId !== 0) {
+				$threadAttendees = $this->threadService->findAttendeeByThreadIds($attendee, [$threadId]);
+				$threadAttendee = array_shift($threadAttendees);
+				if ($threadAttendee !== null && $threadAttendee->getNotificationLevel() !== Participant::NOTIFY_DEFAULT) {
+					$notificationLevel = $threadAttendee->getNotificationLevel();
+				}
+			}
+
 			if ($notificationLevel === Participant::NOTIFY_DEFAULT) {
 				if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 					$notificationLevel = Participant::NOTIFY_ALWAYS;
