@@ -16,6 +16,7 @@ use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
+use OCA\Talk\Service\RoomService;
 use OCP\AppFramework\Db\TTransactional;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Cache\CappedMemoryCache;
@@ -60,6 +61,7 @@ class RoomShareProvider implements IShareProvider {
 		private IEventDispatcher $dispatcher,
 		private Manager $manager,
 		private ParticipantService $participantService,
+		protected RoomService $roomService,
 		protected ITimeFactory $timeFactory,
 		private IL10N $l,
 		private IMimeTypeLoader $mimeTypeLoader,
@@ -79,6 +81,7 @@ class RoomShareProvider implements IShareProvider {
 	 *
 	 * @return string Containing only [a-zA-Z0-9]
 	 */
+	#[\Override]
 	public function identifier(): string {
 		return 'ocRoomShare';
 	}
@@ -90,6 +93,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @return IShare The share object
 	 * @throws GenericShareException
 	 */
+	#[\Override]
 	public function create(IShare $share): IShare {
 		try {
 			$room = $this->manager->getRoomByToken($share->getSharedWith(), $share->getSharedBy());
@@ -150,6 +154,8 @@ class RoomShareProvider implements IShareProvider {
 			return $this->getRawShare($shareId);
 		}, $this->dbConnection);
 
+		$this->roomService->setHasAttachments($room);
+
 		return $this->createShareObject($data);
 	}
 
@@ -278,6 +284,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @param IShare $share
 	 * @return IShare The share object
 	 */
+	#[\Override]
 	public function update(IShare $share): IShare {
 		$this->cleanSharesByIdCache();
 
@@ -323,6 +330,7 @@ class RoomShareProvider implements IShareProvider {
 	 *
 	 * @param IShare $share
 	 */
+	#[\Override]
 	public function delete(IShare $share): void {
 		$this->cleanSharesByIdCache();
 
@@ -344,6 +352,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @param IShare $share
 	 * @param string $recipient UserId of the recipient
 	 */
+	#[\Override]
 	public function deleteFromSelf(IShare $share, $recipient): void {
 		$this->cleanSharesByIdCache();
 
@@ -398,6 +407,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @return IShare The restored share object
 	 * @throws GenericShareException In case the share could not be restored
 	 */
+	#[\Override]
 	public function restore(IShare $share, string $recipient): IShare {
 		$this->cleanSharesByIdCache();
 
@@ -440,6 +450,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @param string $recipient userId of recipient
 	 * @return IShare
 	 */
+	#[\Override]
 	public function move(IShare $share, $recipient): IShare {
 		$this->cleanSharesByIdCache();
 
@@ -499,6 +510,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @return IShare[][]
 	 * @psalm-return array<array-key, non-empty-list<IShare>>
 	 */
+	#[\Override]
 	public function getSharesInFolder($userId, Folder $node, $reshares, $shallow = true): array {
 		$qb = $this->dbConnection->getQueryBuilder();
 		$qb->select('s.*',
@@ -560,6 +572,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @param int $offset
 	 * @return IShare[]
 	 */
+	#[\Override]
 	public function getSharesBy($userId, $shareType, $node, $reshares, $limit, $offset): array {
 		$qb = $this->dbConnection->getQueryBuilder();
 		$qb->select('*')
@@ -610,6 +623,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @return IShare
 	 * @throws ShareNotFound
 	 */
+	#[\Override]
 	public function getShareById($id, $recipientId = null): IShare {
 		if (($recipientId === null) && isset($this->sharesByIdCache[$id])) {
 			$share = $this->sharesByIdCache[$id];
@@ -746,6 +760,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @param Node $path
 	 * @return IShare[]
 	 */
+	#[\Override]
 	public function getSharesByPath(Node $path): array {
 		$qb = $this->dbConnection->getQueryBuilder();
 
@@ -774,21 +789,19 @@ class RoomShareProvider implements IShareProvider {
 	 * @param int $offset
 	 * @return IShare[]
 	 */
+	#[\Override]
 	public function getSharedWith($userId, $shareType, $node, $limit, $offset): array {
-		$allRooms = $this->manager->getRoomTokensForUser($userId);
+		$allRooms = $this->manager->getRoomTokensWithAttachmentsForUser($userId);
+
+		if (empty($allRooms)) {
+			return [];
+		}
 
 		/** @var IShare[] $shares */
 		$shares = [];
 
-		$start = 0;
-		while (true) {
-			$rooms = array_slice($allRooms, $start, 100);
-			$start += 100;
-
-			if ($rooms === []) {
-				break;
-			}
-
+		$chunks = array_chunk($allRooms, 100);
+		foreach ($chunks as $rooms) {
 			$qb = $this->dbConnection->getQueryBuilder();
 			$qb->select('s.*',
 				'f.fileid', 'f.path', 'f.permissions AS f_permissions', 'f.storage', 'f.path_hash',
@@ -814,14 +827,14 @@ class RoomShareProvider implements IShareProvider {
 				->andWhere($qb->expr()->in('s.share_with', $qb->createNamedParameter(
 					$rooms,
 					IQueryBuilder::PARAM_STR_ARRAY
-				)))
-				->andWhere($qb->expr()->orX(
-					$qb->expr()->eq('s.item_type', $qb->createNamedParameter('file')),
-					$qb->expr()->eq('s.item_type', $qb->createNamedParameter('folder'))
-				));
+				)));
 
 			$cursor = $qb->executeQuery();
 			while ($data = $cursor->fetch()) {
+				if ($data['uid_initiator'] === $userId || $data['uid_owner'] === $userId) {
+					continue;
+				}
+
 				if (!$this->isAccessibleResult($data)) {
 					continue;
 				}
@@ -867,6 +880,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @return IShare
 	 * @throws ShareNotFound
 	 */
+	#[\Override]
 	public function getShareByToken($token): IShare {
 		$qb = $this->dbConnection->getQueryBuilder();
 
@@ -903,6 +917,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @param string $uid
 	 * @param int $shareType
 	 */
+	#[\Override]
 	public function userDeleted($uid, $shareType): void {
 		// A deleted user is handled automatically by the room hooks due to the
 		// user being removed from the room.
@@ -915,6 +930,7 @@ class RoomShareProvider implements IShareProvider {
 	 *
 	 * @param string $gid
 	 */
+	#[\Override]
 	public function groupDeleted($gid): void {
 	}
 
@@ -926,6 +942,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @param string $uid
 	 * @param string $gid
 	 */
+	#[\Override]
 	public function userDeletedFromGroup($uid, $gid): void {
 	}
 
@@ -938,6 +955,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @param bool $currentAccess If current access is required (like for removed shares that might get revived later)
 	 * @return array
 	 */
+	#[\Override]
 	public function getAccessList($nodes, $currentAccess): array {
 		$ids = [];
 		foreach ($nodes as $node) {
@@ -1039,6 +1057,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @param IShare $parent
 	 * @return IShare[]
 	 */
+	#[\Override]
 	public function getChildren(IShare $parent): array {
 		$children = [];
 
@@ -1151,6 +1170,7 @@ class RoomShareProvider implements IShareProvider {
 	 * @return iterable
 	 * @since 18.0.0
 	 */
+	#[\Override]
 	public function getAllShares(): iterable {
 		$qb = $this->dbConnection->getQueryBuilder();
 
