@@ -4,6 +4,8 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Types;
 
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Native\ComplianceNode;
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Node;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\ErrorMessage;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\MessageBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\IntegerType;
@@ -20,6 +22,11 @@ final class NonPositiveIntegerType implements IntegerType
         return is_int($value) && $value <= 0;
     }
 
+    public function compiledAccept(ComplianceNode $node): ComplianceNode
+    {
+        return Node::functionCall('is_int', [$node])->and($node->isLessOrEqualsTo(Node::value(0)));
+    }
+
     public function matches(Type $other): bool
     {
         if ($other instanceof UnionType) {
@@ -28,6 +35,7 @@ final class NonPositiveIntegerType implements IntegerType
 
         return $other instanceof self
             || $other instanceof NativeIntegerType
+            || $other instanceof ScalarConcreteType
             || $other instanceof MixedType;
     }
 
@@ -50,6 +58,11 @@ final class NonPositiveIntegerType implements IntegerType
         return MessageBuilder::newError('Value {source_value} is not a valid non-positive integer.')->build();
     }
 
+    public function nativeType(): NativeIntegerType
+    {
+        return NativeIntegerType::get();
+    }
+
     public function toString(): string
     {
         return 'non-positive-int';
